@@ -6,6 +6,7 @@
             [leiningen.core.test.helper :refer [abort-msg]]
             [leiningen.test.helper :as lthelper]
             [leiningen.core.utils :as utils]
+            [leiningen.core.main :as main]
             [clojure.java.io :as io])
   (:import (java.io StringReader)))
 
@@ -409,7 +410,8 @@
 
 (deftest test-global-exclusions
   (let [project {:dependencies
-                 '[[lancet "1.0.1"]
+                 '[[org.clojure/clojure "1.11.1"]
+                   [lancet "1.0.1"]
                    [leiningen-core "2.0.0-SNAPSHOT" :exclusions [pomegranate]]
                    [clucy "0.2.2" :exclusions [org.clojure/clojure]]]
                  :exclusions '[org.clojure/clojure]}
@@ -417,7 +419,11 @@
     (is (= '[[[org.clojure/clojure]]
              [[org.clojure/clojure] [pomegranate/pomegranate]]
              [[org.clojure/clojure]]]
-           (map #(distinct (:exclusions (apply hash-map %))) dependencies)))))
+           (map #(distinct (:exclusions (apply hash-map %))) dependencies)))
+    (is (= '[[lancet/lancet "1.0.1" :exclusions ([org.clojure/clojure])]
+             [leiningen-core/leiningen-core "2.0.0-SNAPSHOT" :exclusions ([org.clojure/clojure] [pomegranate/pomegranate])]
+             [clucy/clucy "0.2.2" :exclusions ([org.clojure/clojure])]]
+           dependencies))))
 
 (defn add-seven [project]
   (assoc project :seven 7))
@@ -489,14 +495,15 @@
              (dissoc :profiles)))))
 
 (deftest test-composite-profiles
-  (is (= {:A '(1 3 2), :B 2, :C 3}
-         (-> (make-project
-              {:profiles {:a [:b :c]
-                          :b [{:A [1] :B 1 :C 1} :d]
-                          :c {:A [2] :B 2}
-                          :d {:A [3] :C 3}}})
-             (merge-profiles [:a])
-             (dissoc :profiles)))))
+  (binding [main/*info* false]
+    (is (= {:A '(1 3 2), :B 2, :C 3}
+           (-> (make-project
+                {:profiles {:a [:b :c]
+                            :b [{:A [1] :B 1 :C 1} :d]
+                            :c {:A [2] :B 2}
+                            :d {:A [3] :C 3}}})
+               (merge-profiles [:a])
+               (dissoc :profiles))))))
 
 (deftest test-profiles-default-meta
   (is (= [:repl]
@@ -556,14 +563,14 @@
           (is (not (:dev? (project/unmerge-profiles project [:dev])))))))))
 
 (deftest test-merge-coll-with-metadata
-  (let [project
-        (-> (make-project
-             {:profiles
-              {:shared {:clean-targets ^{:protect false} ["resources/a.txt"]}
-               :prod [:shared {:clean-targets ^{:protect false} ["resources/b.txt"]}]}})
-            (merge-profiles [:prod]))]
-    (is (= (:clean-targets project) ["resources/a.txt" "resources/b.txt"]))
-    (is (false? (-> project :clean-targets meta :protect)))))
+  (binding [main/*info* false]
+    (let [profiles {:shared {:clean-targets ^{:protect false} ["resources/a.txt"]}
+                    :prod [:shared {:clean-targets
+                                    ^{:protect false} ["resources/b.txt"]}]}
+          project (-> (make-project {:profiles profiles})
+                      (merge-profiles [:prod]))]
+      (is (= (:clean-targets project) ["resources/a.txt" "resources/b.txt"]))
+      (is (false? (-> project :clean-targets meta :protect))))))
 
 (deftest test-dedupe-deps
   (is (= '[[org.clojure/clojure "1.3.0"]
